==> nudge_leaderboard_ui-0.0.5.tar.gz: lib/features/leaderboard/presentation/widgets/leaderboard_scoredata.dart <==
import 'package:nudge_leaderboard_ui/features/leaderboard/data/models/get_nudge_leaderboard.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/appbar/leaderboard_appbar.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/leaderboard_rankers_container.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/rank_container.dart';
import 'package:lazy_load_scrollview/lazy_load_scrollview.dart';
import 'package:flutter/material.dart';

class LeaderboardDataScore extends StatelessWidget {
  final GetNudgeLeaderboard? nudgeleaderboarddata;
  final int currentItemCount;
  final VoidCallback loadMoreData;

  LeaderboardDataScore({
    required this.nudgeleaderboarddata,
    required this.currentItemCount,
    required this.loadMoreData,
  });
  @override
  Widget build(BuildContext context) {
    int usersLength = nudgeleaderboarddata?.data.users.length ?? 0;

    return Scaffold(
      backgroundColor: const Color.fromRGBO(49, 162, 215, 1),
      appBar: LeaderboardAppBar(),
      body: (usersLength >= 5)
          ? Column(
              children: [
                const SizedBox(height: 10),
                Container(
                  width: double.infinity,
                  decoration: const BoxDecoration(
                    color: const Color.fromRGBO(49, 162, 215, 1),
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(20),
                      topRight: Radius.circular(20),
                    ),
                  ),
                  child: Row(
                    children: [
                      LeaderboardRankers(
                        nameRank1:
                            nudgeleaderboarddata?.data.users[0].userId?.name ??
                                'Loading...',
                        pointsRank1:
                            nudgeleaderboarddata?.data.users[0].score ?? 0,
                        nameRank2:
                            nudgeleaderboarddata?.data.users[1].userId?.name ??
                                'Loading...',
                        pointsRank2:
                            nudgeleaderboarddata?.data.users[1].score ?? 0,
                        nameRank3:
                            nudgeleaderboarddata?.data.users[2].userId?.name ??
                                'Loading...',
                        pointsRank3:
                            nudgeleaderboarddata?.data.users[2].score ?? 0,
                        photoUrl1: nudgeleaderboarddata
                            ?.data.users[0].userId?.photoUrl,
                        photoUrl2: nudgeleaderboarddata
                            ?.data.users[1].userId?.photoUrl,
                        photoUrl3: nudgeleaderboarddata
                            ?.data.users[2].userId?.photoUrl,
                      ),
                    ],
                  ),
                ),
                Container(
                  width: double.infinity,
                  decoration: const BoxDecoration(
                    color: Color.fromRGBO(246, 247, 250, 1),
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(20),
                      topRight: Radius.circular(20),
                    ),
                  ),
                  child: Headers(),
                ),
                Expanded(
                  child: Container(
                    decoration: const BoxDecoration(
                      color: Color.fromRGBO(246, 247, 250, 1),
                    ),
                    child: nudgeleaderboarddata == null
                        ? const Center(
                            child: CircularProgressIndicator(
                              strokeWidth: 6,
                              color: Color.fromRGBO(49, 162, 215, 1),
                            ),
                          )
                        : LazyLoadScrollView(
                            onEndOfPage: () => loadMoreData(),
                            child: SingleChildScrollView(
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  RankContainer(
                                    points:
                                        nudgeleaderboarddata?.data.user.score ??
                                            0,
                                    name: nudgeleaderboarddata
                                            ?.data.user.userId?.name ??
                                        'loading....',
                                    rank: nudgeleaderboarddata?.data.rank ?? 0,
                                    photoUrl: nudgeleaderboarddata
                                        ?.data.user.userId?.photoUrl,
                                  ),
                                  for (int index = 0;
                                      index < currentItemCount &&
                                          index <
                                              (nudgeleaderboarddata
                                                      ?.data.users.length ??
                                                  0);
                                      index++)
                                    RankContainer(
                                      points: nudgeleaderboarddata
                                              ?.data.users[index].score ??
                                          0,
                                      name: nudgeleaderboarddata?.data
                                              .users[index].userId?.name ??
                                          'Loading...',
                                      rank: index + 1,
                                      photoUrl: nudgeleaderboarddata
                                          ?.data.users[index].userId?.photoUrl,
                                    ),
                                ],
                              ),
                            ),
                          ),
                  ),
                ),
              ],
            )
          : const Center(
              child: Text(
                "Leaderboard would be enabled after there are atleast 5 users",
                style: TextStyle(
                  fontSize: 20,
                  fontWeight: FontWeight.bold,
                  color: Colors.white,
                ),
              ),
            ),
    );
  }
}

class Headers extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(left: 24.0, top: 16, right: 24, bottom: 8),
      child: Row(
        // mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Padding(
            padding: const EdgeInsets.only(
              left: 16.0,
            ),
            child: Container(
              width: MediaQuery.of(context).size.width * 0.1,
              child: const Text(
                'Rank',
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.normal,
                ),
              ),
            ),
          ),
          const SizedBox(
            width: 25,
          ),
          Container(
            width: MediaQuery.of(context).size.width * 0.50,
            child: const Text(
              'Name',
              style: TextStyle(
                color: Colors.black,
                fontSize: 16,
                fontWeight: FontWeight.normal,
              ),
            ),
          ),
          Container(
            width: MediaQuery.of(context).size.width * 0.15,
            child: const Text(
              'Points',
              style: TextStyle(
                color: Colors.black,
                fontSize: 16,
                fontWeight: FontWeight.normal,
              ),
            ),
          ),
        ],
      ),
    );
  }
}

==> nudge_leaderboard_ui-0.0.9.tar.gz: lib/features/leaderboard/presentation/widgets/leaderboard_scoredata.dart <==
import 'dart:developer';

import 'package:nudge_leaderboard_ui/features/leaderboard/data/models/get_nudge_leaderboard.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/appbar/leaderboard_appbar.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/leaderboard_rankers_container.dart';
import 'package:nudge_leaderboard_ui/features/leaderboard/presentation/widgets/rank_container.dart';
import 'package:lazy_load_scrollview/lazy_load_scrollview.dart';
import 'package:flutter/material.dart';

class LeaderboardDataScore extends StatelessWidget {
  final GetNudgeLeaderboard? nudgeLeaderboardData;
  final int currentItemCount;
  final int currentPageNo;
  final VoidCallback loadMoreData;
  final Function(int, int) refreshDataOnDateChanged;

  const LeaderboardDataScore({
    super.key,
    required this.nudgeLeaderboardData,
    required this.currentItemCount,
    required this.currentPageNo,
    required this.loadMoreData,
    required this.refreshDataOnDateChanged,
  });

  @override
  Widget build(BuildContext context) {
    int usersLength = nudgeLeaderboardData?.data.users.length ?? 0;

    log('usersLength: $usersLength', name: 'leaderboard');

    return Scaffold(
      backgroundColor: const Color.fromRGBO(49, 162, 215, 1),
      appBar: LeaderboardAppBar(
        refreshDataOnDateChanged: refreshDataOnDateChanged,
      ),
      body: (usersLength >= 5)
          ? Column(
              children: [
                const SizedBox(height: 10),
                Container(
                  width: double.infinity,
                  decoration: const BoxDecoration(
                    color: Color.fromRGBO(49, 162, 215, 1),
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(20),
                      topRight: Radius.circular(20),
                    ),
                  ),
                  child: Row(
                    children: [
                      LeaderboardRankers(
                        nameRank1:
                            nudgeLeaderboardData?.data.users[0].userId?.name ??
                                'Loading...',
                        pointsRank1:
                            nudgeLeaderboardData?.data.users[0].score ?? 0,
                        nameRank2:
                            nudgeLeaderboardData?.data.users[1].userId?.name ??
                                'Loading...',
                        pointsRank2:
                            nudgeLeaderboardData?.data.users[1].score ?? 0,
                        nameRank3:
                            nudgeLeaderboardData?.data.users[2].userId?.name ??
                                'Loading...',
                        pointsRank3:
                            nudgeLeaderboardData?.data.users[2].score ?? 0,
                        photoUrl1: nudgeLeaderboardData
                            ?.data.users[0].userId?.photoUrl,
                        photoUrl2: nudgeLeaderboardData
                            ?.data.users[1].userId?.photoUrl,
                        photoUrl3: nudgeLeaderboardData
                            ?.data.users[2].userId?.photoUrl,
                      ),
                    ],
                  ),
                ),
                Container(
                  alignment: Alignment.centerLeft,
                  padding: const EdgeInsets.fromLTRB(
                    30,
                    10,
                    0,
                    10,
                  ),
                  child: const Text(
                    'You',
                    style: TextStyle(
                      fontSize: 18,
                      color: Colors.white,
                    ),
                  ),
                ),
                RankContainer(
                  points: nudgeLeaderboardData?.data.user.score ?? 0,
                  name: nudgeLeaderboardData?.data.user.userId?.name ??
                      'loading....',
                  rank: nudgeLeaderboardData?.data.rank ?? 0,
                  photoUrl: nudgeLeaderboardData?.data.user.userId?.photoUrl,
                ),
                const SizedBox(
                  height: 10,
                ),
                Container(
                  width: double.infinity,
                  decoration: const BoxDecoration(
                    color: Color.fromRGBO(246, 247, 250, 1),
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(20),
                      topRight: Radius.circular(20),
                    ),
                  ),
                  child: Headers(),
                ),
                Expanded(
                  child: Container(
                    decoration: const BoxDecoration(
                      color: Color.fromRGBO(246, 247, 250, 1),
                    ),
                    child: nudgeLeaderboardData == null
                        ? const Center(
                            child: CircularProgressIndicator(
                              strokeWidth: 6,
                              color: Color.fromRGBO(49, 162, 215, 1),
                            ),
                          )
                        : LazyLoadScrollView(
                            onEndOfPage: () => loadMoreData(),
                            child: SingleChildScrollView(
                              child: Column(
                                crossAxisAlignment: CrossAxisAlignment.start,
                                children: [
                                  for (int index = 0;
                                      index < currentItemCount &&
                                          index <
                                              (nudgeLeaderboardData
                                                      ?.data.users.length ??
                                                  0);
                                      index++)
                                    RankContainer(
                                      points: nudgeLeaderboardData
                                              ?.data.users[index].score ??
                                          0,
                                      name: nudgeLeaderboardData?.data
                                              .users[index].userId?.name ??
                                          'Loading...',
                                      rank: index + 1,
                                      photoUrl: nudgeLeaderboardData
                                          ?.data.users[index].userId?.photoUrl,
                                    ),
                                ],
                              ),
                            ),
                          ),
                  ),
                ),
              ],
            )
          : const Center(
              child: Text(
                "Leaderboard would be enabled after there are atleast 5 users",
                style: TextStyle(
                  fontSize: 20,
                  fontWeight: FontWeight.bold,
                  color: Colors.white,
                ),
              ),
            ),
    );
  }
}

class Headers extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(
        left: 22.0,
        top: 16,
        right: 24,
        bottom: 8,
      ),
      child: Row(
        // mainAxisAlignment: MainAxisAlignment.spaceBetween,
        children: [
          Expanded(
            flex: 1,
            child: Container(
              padding: const EdgeInsets.only(left: 10.0),
              child: const Text(
                'Rank',
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.normal,
                ),
              ),
            ),
          ),
          Expanded(
            flex: 3,
            child: Container(
              padding: const EdgeInsets.only(left: 25.0),
              child: const Text(
                'Name',
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.normal,
                ),
              ),
            ),
          ),
          Expanded(
            flex: 1,
            child: Container(
              padding: const EdgeInsets.only(left: 10.0),
              width: MediaQuery.of(context).size.width * 0.15,
              child: const Text(
                'Points',
                style: TextStyle(
                  color: Colors.black,
                  fontSize: 16,
                  fontWeight: FontWeight.normal,
                ),
              ),
            ),
          ),
        ],
      ),
    );
  }
}
